<?php

/**
 * FR_Presenter_smarty
 *
 * @author Dirk Herbes <d.herbes@fair-computer.de>
 * @copyright Dirk Herbes <d.herbes@fair-computer.de>
 * @package Framework
 * @filesource
 */
require_once(SMARTY_DIR . 'Smarty.class.php');

/**
 * FR_Presenter_smarty
 *
 * By default we use Smarty as our websites presentation layer (view). Smarty
 * is a robust compiling template engine with an active community.
 *
 * @author Dirk Herbes <d.herbes@fair-computer.de>
 * @package Framework
 * @link http://smarty.php.net
 */
class FR_Presenter_smarty extends FR_Presenter_localization {

    private $template = null;
    private $path = null;

    public function __construct(FR_Module $module) {
        parent::__construct($module);

        $this->path = _HM_BASE . '/tpl/' . FR_TEMPLATE;
        $this->template = new Smarty();
        $this->template->left_delimiter = '[%';
        $this->template->right_delimiter = '%]';
        $this->template->template_dir = $this->path . '/' . 'templates';
        $this->template->compile_dir = $this->path . '/' . 'templates_c';
        $this->template->cache_dir = $this->path . '/' . 'cache';
        $this->template->config_dir = $this->path . '/' . 'config';

        $this->template->assign('CSSTEMPLATE', CSSTEMPLATE);

        if (@$_SESSION['GlobalConnect'] == 1) {
            $baseurl = @$_SESSION['BaseURL'];
            $this->template->assign('junction', trim(@$_SESSION['Junction']));
        } else {
            if (defined("GLOBALCONNECT_IP") && $_SERVER['REMOTE_ADDR'] == GLOBALCONNECT_IP) {
                $baseurl = GLOBALCONNECT_URL;
            } else {
                $baseurl = (isset($_SERVER['HTTPS'])) ? 'https://' : 'http://';
                $baseurl .= $_SERVER['HTTP_HOST'] . '/';
            }
        }
        $baseurl = urldecode($baseurl);
        $this->template->assign('portalurl', $baseurl);
    }

    public function display() {
        $path = _HM_BASE . '/modules/' . $this->module->moduleName . '/tpl';

        $tplFile = $this->module->tplFile;

        $uri = @$_SERVER['REQUEST_URI'];
        $uri = preg_replace('/language=.*&|language=.*$/Uis', '', $uri);
        if (substr($uri, -1) == '?') {
            $uri = substr($uri, 0, -1);
        }

        $uri_clue = (strpos($uri, '?') !== false) ? '&' : '?';


        $module_name = $this->module->moduleName;
        $class_name = $this->module->className;
        $event_name = $this->module->eventName;


        $url = $module_name;
        if ($class_name != $module_name)
            $url .= '/' . $class_name;
        if ($event_name != '__default')
            $url .= '/' . $event_name;
        $url .= '.html';
        $this->template->assign('baseurl', $this->module->baseurl);
        $this->template->assign('gb', $url);
//            $this->template->assign('gbclue', $uri_clue);
        $this->template->assign('modulePath', $path);
        $this->template->assign('tplFile', $tplFile);

        $this->template->assign('user', $this->user);
        $this->template->assign('session', $this->session);
        $this->template->assign('AssetDesk', (defined('ASSETDESK') && ASSETDESK == 1) ? 1 : 0 );

        // Base Template Settings
        $this->template->assign('show_language', $this->module->show_language);
        $this->template->assign('show_font', $this->module->show_font);
        $this->template->assign('show_help', $this->module->show_help);
        $this->template->assign('show_print', $this->module->show_print);
        $this->template->assign('page_title', $this->module->page_title);
        $this->template->assign('portal_name', (defined("FR_PORTAL_NAME")) ? FR_PORTAL_NAME : '');


        foreach ($this->module->getData() as $var => $val) {
            if (!in_array($var, array('path', 'tplFile'))) {
                $this->template->assign($var, $val);
            }
        }

        $content = $this->template->fetch($path . '/' . $tplFile);
        $this->template->assign('content', $content);


        //Benutzerdefinierte-Styleanpassungen:
        try {
//echo "<h2>angepasste Styles</h2>";
            if (is_writable(_HM_BASE . '/' . _HM_STYLEPATH)) {
//echo "<br/>".__LINE__.": Stylepfad ist beschreibbar";
                if (!isset($_SESSION['LoadedStyle']) || !file_exists(_HM_BASE . "/" .$_SESSION['LoadedStyle'])) {
//echo "<br/>".__LINE__.": Datei fr Style [".$_SESSION['LoadedStyle']."] existiert nicht... ";
                    $LoadedStyle = $this->tools->getStyle();
//echo "<br/>".__LINE__.": Style [".$LoadedStyle['StyleName']."] soll verwendet werden und wurde aus DB geladen... ";
//echo "<pre>";
//print_r($LoadedStyle);
//echo "</pre>";
                    if (isset($LoadedStyle['Definitions']) && count($LoadedStyle['Definitions']) && isset($LoadedStyle['Definitions']['StyleName']) && isset($LoadedStyle['Definitions']['CreateDate'])) {
//echo "<br/>".__LINE__.":Style [".$LoadedStyle['Definitions']['StyleName']."] wird verarbeitet... ";
                        $PathToStyle = _HM_STYLEPATH . $LoadedStyle['Definitions']['StyleName'] . ".css";
                        $filename = _HM_BASE . "/" . $PathToStyle;
//echo " ".$this->tools->ToUnixTimestamp($LoadedStyle['CreateDate'])."==".$LoadedStyle['Definitions']['CreateDate']." ?";                        
                        if (!file_exists($filename) || filemtime($filename) < $LoadedStyle['Definitions']['CreateDate']) {
//echo "<br/>".__LINE__.": Datei existiert nicht oder ist lter als Definition [".$LoadedStyle['CreateDate']."] aus DB ... ";

                            //jk 12.06.2014: LESS fr CSS-Templates einbinden:
                            // http://leafo.net/lessphp/docs/
                            require_once _HM_BASE . '/includes/lessc.inc.php';
                            $less = new lessc;

                            $less->setVariables($LoadedStyle['Definitions']);
                            @unlink($filename);
                            $less->setFormatter("compressed");
                            $less->checkedCompile(_HM_BASE . "/styles/less/screen.less", $filename);
//echo "<br/>".__LINE__.": Style compiliert und Datei [$filename] neu angelegt ...";
                        }
                    }
                } else {
                    $PathToStyle = $_SESSION['LoadedStyle'];
                    $filename = _HM_BASE . "/" . $PathToStyle;
//echo "<br/>".__LINE__.": Style compiliert und Datei [$filename] wird verwendet.";
                }

                if (isset($filename) && file_exists($filename)) {
//echo "<br/>".__LINE__.": Pfad [$PathToStyle] wurde als LESSStylePath ans Template bergeben.";
                    $this->template->assign("LESSStylePath", $PathToStyle);
                    $_SESSION['LoadedStyle'] = $PathToStyle;
                }
            }
        } catch (Exception $exc) {
//echo "<br/>".__LINE__.": Exception beim laden des Styles aufgetreten: ";
            echo $exc->getTraceAsString();
        }
        //Nachrichtenwesen:
            $ShowMessages = (defined("SHOWMESSAGES") && SHOWMESSAGES == 0) ? false : true;
            $this->template->assign("ShowMessages", $ShowMessages);

        if ($this->module->pageTemplateFile == null) {
            $pageTemplateFile = 'page.tpl';
        } else {
            $pageTemplateFile = $this->module->pageTemplateFile;
        }

        // header('Content-type: text/html; charset=utf-8');
        $this->template->display($pageTemplateFile);
    }

    public function __destruct() {
        parent::__destruct();
    }

}

?>